# FCPX插件管理器开发需求文档

## 📋 项目概述

### 项目名称
**FCPX插件管理器 (TemmplatesArchive)**

### 项目描述
一个专为Final Cut Pro X设计的插件管理工具，支持查看、管理、卸载、重命名和合并各类FCPX插件，特别针对FxFactory插件的UUID命名问题提供了完整的解决方案。


1. **插件扫描路径配置修复**
   - 系统插件路径：`/Library/Application Support/Final Cut Pro/Templates.localized`
   - 验证FxPlug插件路径：`/Library/Plug-Ins/FxPlug` 
   - 用户插件路径：`~/Movies/Motion Templates.localized` 


- FCPX插件目录结构：
  - `Generators.localized` (发生器)
  - `Effects.localized` (效果)
  - `Titles.localized` (字幕)
  - `Transitions.localized` (转场)
  - `Compositions.localized` (合成)

插件层级关系
插件源（系统插件或者用户插件）/插件类型（效果或者字幕）/类别目录/主题目录（部分插件才有这个目录）/插件目录/插件本体（包含moti、motn等文件，缩略图）

在用户插件中有一类特殊的Fxfactory插件，它的结构和普通插件一样，只是类别目录和插件目录都是UUID.localized的形式，插件本体也是UUID，他们的真实文件名存储在隐藏文件en.strings中，在初始化阶段需要从这个文件中读取真实文件名显示在视图中方便用户辨识。同时，如果用户对该类插件进行重命名或者合并操作，需要将文件名还原为真实文件名，去掉所有的.localized后缀和删除目录下所有的隐藏文件。同时需要在视图中对该类型插件进行图标上的区分

-Fxplug插件目录
/Library/Plug-Ins/FxPlug（该目录下只有APP应用，不支持重命名和合并，删除需要管理员权限）


### 技术要求
- **平台**: macOS 12.0及以上版本
- **框架**: SwiftUI作为主要UI框架
- **语言**: Swift 5.0及以上版本
- **架构**: 支持Apple Silicon和Intel Mac的通用二进制
- **权限**: 需要系统目录访问、文件管理和AppleScript执行权限



## 🎯 核心功能模块

### 1. 插件扫描与管理系统


读取插件源路径中的插件目录，以插件源-插件类型-类别目录-插件本体含缩略图的分栏视图显示在主视图中

FxFactory插件管理系统使用UUID（通用唯一标识符）来命名插件目录和文件，这导致用户在文件系统中看到的都是类似"12345678-1234-1234-1234-123456789ABC"的无意义字符串，严重影响用户体验和插件识别。需要进行文件名还原显示



#### 2.3 防护机制设计
FxFactory具有自动重新安装机制，当检测到插件被删除或者重命名时会自动重新安装。因此在进行FxFactory插件操作(重命名、卸载、合并）时，需要实施防护机制：/Library/Application Support/FxFactory目录下查找和被操作的插件同名的fxpack文件和fxtemplates文件，在用户更名合并或者移除后同步删除这两个文件。例如用户对真实文件名为“Adjustment Layers”的Fxfactory插件进行了重命名、合并或者删除操作，需要同步删除/Library/Application Support/FxFactory目录下的Adjustment Layers.fxpack和Adjustment Layers.fxtemplates这两个文件。因为用户进行上述操作后，该插件不再由Fxfactory管理，因此需要删除这两个文件，防止Fxfactory再次自动安装该插件。同时将原本Fxfactory独特的文件名命名方式还原为普通插件的命名方式，移除UUID命名和.localized结构。删除插件目录下的所有隐藏文件

### 3. 插件操作功能体系

#### 3.1 查看和展示功能
**多视图模式支持**：应用应支持网格视图和列表视图两种展示模式，用户可以根据偏好选择。网格视图适合快速浏览缩略图，列表视图适合查看详细信息。

**缩略图管理**：实现智能缩略图缓存系统，支持异步加载和内存管理。缩略图应该从插件的thumbnail文件中读取，如果不存在则显示默认占位图。

**信息展示**：每个插件应显示名称、文件大小、修改时间、插件类型等关键信息。对于FxFactory插件，应特别标识其特殊性质。

**统计功能**：实时计算和显示插件数量、总体积等统计信息，帮助用户了解插件使用情况。

#### 3.2 卸载功能实现
**分类处理策略**：不同类型的插件需要采用不同的卸载策略。普通用户插件可以直接移动到回收站，FxFactory插件需要防护机制，FxPlug插件需要管理员权限，PlugKit插件需要命令行操作。

**安全确认机制**：所有卸载操作都应该有明确的用户确认步骤，显示将要删除的内容和可能的影响。

**回滚支持**：对于移动到回收站的操作，用户应该能够从回收站恢复。对于永久删除的操作，应该有明确的警告。

#### 3.3 重命名功能设计
**三级同步重命名**：FCPX插件的重命名涉及三个层级的同步更新：类别目录名称、插件目录名称和插件文件名称。所有层级都必须保持一致性。

**冲突检测和处理**：重命名前需要检查目标名称是否已存在，如果存在冲突，应提供自动添加后缀或用户自定义解决方案。

**FxFactory特殊处理**：对于FxFactory插件，重命名操作实际上是将其转换为普通插件的过程，需要移除UUID命名和.localized结构。

#### 3.4 合并功能架构
**类型一致性验证**：只有相同子类型的插件才能进行合并操作。系统需要验证用户选择的插件是否满足合并条件。



**批量处理能力**：支持同时合并多个插件到同一目标类别，提高操作效率。

**冲突解决机制**：当合并过程中出现同名冲突时，提供多种解决方案：自动重命名、用户自定义名称、跳过冲突项等。

### 4. 权限和安全管理体系

#### 4.1 分层权限管理
**文件系统权限**：应用需要获得访问用户目录和系统目录的权限。对于系统目录的访问，需要特别的权限检查和错误处理。

**管理员权限**：对于需要管理员权限的操作（如FxPlug插件删除），应使用系统标准的权限提升机制，通过AppleScript调用系统密码输入界面。

**沙盒兼容性**：如果应用需要在App Store分发，需要考虑沙盒限制和相应的权限申请。

#### 4.2 FxFactory进程管理
**进程检测**：实现可靠的FxFactory进程检测机制，能够识别所有相关的进程和服务。

**安全终止**：提供安全的进程终止方法，避免数据丢失或系统不稳定。

**用户交互**：当自动终止失败时，提供清晰的用户指导，说明如何手动关闭FxFactory。


## 📊 数据模型设计

### 1. 核心数据结构

#### 1.1 插件源定义
应用需要定义清晰的插件类型枚举，包含以下类型：
- **系统插件（system）**：存储在系统目录中的插件
- **用户插件（user）**：存储在用户目录中的插件
- **FxPlug插件（fxplug）**：系统级别的FxPlug插件


#### 1.2 插件子类型分类
每个插件类型都应支持以下子类型（Fxplug插件除外）：
- **发生器（Generators）**：对应Generators.localized目录
- **效果（Effects）**：对应Effects.localized目录
- **字幕（Titles）**：对应Titles.localized目录
- **转场（Transitions）**：对应Transitions.localized目录






## 🎨 用户界面设计

### 1. 整体布局架构

#### 1.1 三栏布局设计
应用采用经典的三栏布局结构，提供清晰的信息层次和操作流程：

**左侧插件分类栏（固定宽度200像素）**：
- 显示所有可用的插件源类型
- 每个插件源下显示对应的子类型分类
- 支持展开/折叠功能



**中间插件内容区域（自适应宽度）**：
- 主要的插件展示和操作区域
- 支持网格视图
- 包含搜索和筛选功能
- 显示插件数量和总体积统计
- 支持多选和批量操作

**右侧合并操作区域（固定宽度250像素）**：
- 合并操作的专用工作区
- 显示待合并插件的缓冲区
- 提供合并操作的控制按钮
- 显示合并操作的状态和进度

#### 1.2 顶部工具栏设计
工具栏应包含以下核心功能：
- 刷新按钮：手动触发插件扫描
- 视图切换按钮：在网格和列表视图间切换
- 搜索框：实时搜索插件
- 设置按钮：访问应用设置（如果需要）

### 2. 插件展示设计

#### 2.1 网格视图卡片设计
每个插件卡片应包含以下元素：
- **缩略图区域**：显示插件的预览图，支持异步加载和占位图
- **插件名称**：显示用户友好的插件名称，支持多行显示
- **类型标识**：通过图标或颜色标识插件类型和来源
- **FxFactory标识**：特殊图标标识FxFactory插件
- **文件大小**：以人类可读格式显示插件占用空间
- **操作按钮**：鼠标悬停时显示快速操作按钮
- **选择状态**：支持多选模式的视觉反馈


### 3. 交互设计规范

#### 3.1 右键菜单系统
为不同类型的插件提供相应的右键菜单选项：
- **通用操作**：在访达中显示、重命名、卸载
- **合并操作**：合并到其他类别（FxPlug插件除外）
- **FxFactory特殊操作**：还原为普通插件
- **批量操作**：当选中多个插件时的批量操作选项


#### 3.4 多选和批量操作
支持高效的批量操作：
- **框选**：在网格视图中支持鼠标框选
- **Shift点击**：连续选择多个项目
- **Command点击**：非连续选择多个项目
- **批量操作面板**：选中多个项目时显示批量操作选项




