//
//  MergeOperationView.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

// MARK: - 数据模型
enum MergeBufferItemType {
    case plugin(FCPXPlugin)
    case category(CategoryInfo)
}

struct MergeBufferItem: Identifiable, Hashable {
    let id = UUID()
    let type: MergeBufferItemType
    let name: String
    let path: String
    let subType: PluginSubType?
    let pluginCount: Int?
    
    func hash(into hasher: inout Hasher) {
        hasher.combine(id)
    }
    
    static func == (lhs: MergeBufferItem, rhs: MergeBufferItem) -> Bool {
        lhs.id == rhs.id
    }
}

struct MergeOperationView: View {
    @State private var showingCategoryMergeView = false
    @State private var selectedSourceCategory: String = ""
    @State private var selectedTargetCategory: String = ""
    @State private var selectedSourceType: PluginType = .user
    @State private var selectedSubType: PluginSubType = .titles
    
    // 添加刷新回调
    let onMergeComplete: (() -> Void)?

    init(onMergeComplete: (() -> Void)? = nil) {
        self.onMergeComplete = onMergeComplete
    }

    var body: some View {
        VStack(alignment: .leading, spacing: 0) {
            // 标题栏
            HStack {
                Text("合并操作")
                    .font(.headline)
                    .foregroundColor(.primary)

                Spacer()
            }
            .padding(.horizontal, 16)
            .padding(.vertical, 12)
            .background(Color(NSColor.controlBackgroundColor))

            Divider()

            // 合并操作内容
            VStack(spacing: 20) {
                Spacer()

                Image(systemName: "arrow.triangle.merge")
                    .font(.system(size: 48))
                    .foregroundColor(.accentColor)

                VStack(spacing: 12) {
                    Text("类别合并")
                        .font(.title2)
                        .fontWeight(.semibold)
                        .foregroundColor(.primary)

                    Text("合并两个类别中的插件到一个目标类别")
                        .font(.body)
                        .foregroundColor(.secondary)
                        .multilineTextAlignment(.center)
                }

                Button("开始类别合并") {
                    showingCategoryMergeView = true
                }
                .buttonStyle(.borderedProminent)
                .controlSize(.large)

                Spacer()
            }
            .frame(maxWidth: .infinity, maxHeight: .infinity)
            .padding(20)
        }
        .background(
            RoundedRectangle(cornerRadius: 8)
                .fill(Color(NSColor.controlBackgroundColor))
        )
        .sheet(isPresented: $showingCategoryMergeView) {
            // 这里需要一个类别选择和合并的界面
            // 暂时显示一个占位视图
            VStack {
                Text("类别合并功能")
                    .font(.title)
                Text("此功能正在开发中")
                    .foregroundColor(.secondary)
                Button("关闭") {
                    showingCategoryMergeView = false
                }
                .buttonStyle(.borderedProminent)
            }
            .padding()
            .frame(width: 400, height: 300)
        }
    }
}

#Preview {
    MergeOperationView()
        .frame(width: 220, height: 400)
}
