//
//  TemmplatesArchiveApp.swift
//  TemmplatesArchive
//
//  Created by dayu on 2025/7/4.
//

import SwiftUI

@main
struct TemmplatesArchiveApp: App {

    init() {
        print("🚀 应用开始启动...")

        // 延迟执行系统兼容性检查，避免阻塞启动
        Task.detached(priority: .background) {
            SystemCompatibilityManager.shared.checkSystemCompatibility()
        }

        print("🚀 应用启动完成，后台任务已启动")
    }

    var body: some Scene {
        WindowGroup {
            ContentView()
                .frame(minWidth: 1200, minHeight: 800)
        }

    }

    // MARK: - 系统信息日志
    private func logSystemInfo() {
        _ = ProcessInfo.processInfo
        //print("🖥️ ========== 系统信息 ==========")
        //print("📱 应用版本: \(Bundle.main.infoDictionary?["CFBundleShortVersionString"] as? String ?? "未知")")
        //print("🍎 系统版本: \(processInfo.operatingSystemVersionString)")
        //print("💻 架构: \(getMachineArchitecture())")
        //print("💾 物理内存: \(processInfo.physicalMemory / 1024 / 1024 / 1024)GB")
        //print("🔧 处理器数量: \(processInfo.processorCount)")
        //print("👤 用户名: \(NSUserName())")
        //print("📁 主目录: \(NSHomeDirectory())")
        //print("🛡️ 沙盒状态: \(isRunningInSandbox() ? "启用" : "禁用")")
        //print("===============================")
    }

    // MARK: - 系统兼容性检查
    private func checkSystemCompatibility() {
        let osVersion = ProcessInfo.processInfo.operatingSystemVersion

        // 检查最低系统要求 (macOS 12.0)
        if osVersion.majorVersion < 12 {
            //print("⚠️ 警告: 系统版本过低 (\(osVersion.majorVersion).\(osVersion.minorVersion))，可能存在兼容性问题")
        }

        // 检查内存
        let memoryGB = ProcessInfo.processInfo.physicalMemory / 1024 / 1024 / 1024
        if memoryGB < 8 {
            //print("⚠️ 警告: 系统内存较低 (\(memoryGB)GB)，建议至少8GB内存")
        }

        // 检查关键目录权限
        checkDirectoryPermissions()
    }

    // MARK: - 获取机器架构
    private func getMachineArchitecture() -> String {
        var systemInfo = utsname()
        uname(&systemInfo)
        let machine = withUnsafePointer(to: &systemInfo.machine) {
            $0.withMemoryRebound(to: CChar.self, capacity: 1) {
                String(validatingUTF8: $0)
            }
        }
        return machine ?? "未知"
    }

    // MARK: - 检查是否在沙盒中运行
    private func isRunningInSandbox() -> Bool {
        let environment = ProcessInfo.processInfo.environment
        return environment["APP_SANDBOX_CONTAINER_ID"] != nil
    }

    // MARK: - 检查关键目录权限
    private func checkDirectoryPermissions() {
        let criticalPaths = [
            NSHomeDirectory() + "/Movies/Motion Templates.localized",
            "/Library/Application Support/Final Cut Pro/Templates.localized",
            "/Library/Plug-Ins/FxPlug"
        ]

        for path in criticalPaths {
            let fileManager = FileManager.default
            _ = fileManager.isReadableFile(atPath: path)
            let exists = fileManager.fileExists(atPath: path)

            if exists {
                //print("📂 \(path): \(isReadable ? "✅ 可访问" : "❌ 权限不足")")
            } else {
                //print("📂 \(path): ⚠️ 不存在")
            }
        }
    }
}
