//
//  AuthorizationStatusView.swift
//  TemmplatesArchive
//
//  Created by Assistant on 2025-07-15.
//

import SwiftUI

// MARK: - 权限状态显示组件
struct AuthorizationStatusView: View {
    @ObservedObject private var sudoManager = SudoPermissionManager.shared
    
    var body: some View {
        HStack(spacing: 8) {
            // 状态指示器
            Circle()
                .fill(sudoManager.isRequestingPermission ? .blue : .gray)
                .frame(width: 8, height: 8)
            
            // 状态文本
            Text(sudoManager.isRequestingPermission ? "正在请求权限..." : "权限管理")
                .font(.caption)
                .foregroundColor(.secondary)
            
            // 错误信息（如果有）
            if let error = sudoManager.lastError {
                Button(action: {
                    sudoManager.clearError()
                }) {
                    Image(systemName: "exclamationmark.triangle.fill")
                        .foregroundColor(.orange)
                        .font(.caption)
                }
                .buttonStyle(PlainButtonStyle())
                .help("点击清除错误: \(error)")
            }
        }
        .padding(.horizontal, 8)
        .padding(.vertical, 4)
        .background(Color(NSColor.controlBackgroundColor))
        .cornerRadius(6)
    }
}

// MARK: - 预览
#Preview {
    AuthorizationStatusView()
        .padding()
        .frame(width: 400)
}
