# 权限管理系统说明

## 概述

权限管理系统已简化为直接使用 AppleScript 的方式。每次需要管理员权限的操作都会弹出系统的权限对话框，用户输入密码后即可完成操作。这种方式简单可靠，避免了复杂的权限会话管理问题。

## 主要特性

### 1. 简单直接的权限管理
- 每次需要权限时直接弹出系统权限对话框
- 使用 AppleScript 的 `with administrator privileges` 功能
- 无需复杂的会话管理和权限缓存

### 2. 统一的权限接口
- `SudoPermissionManager.shared.deleteFileWithSudoPermission(at:)` - 删除单个文件
- `SudoPermissionManager.shared.deleteFilesWithSudoPermission(_:)` - 批量删除文件
- `SudoPermissionManager.shared.renameFileWithSudoPermission(from:to:)` - 重命名文件
- `SudoPermissionManager.shared.executeAppleScriptCommand(_:)` - 执行自定义权限命令

### 3. 可靠的错误处理
- 完善的错误信息反馈
- 用户取消操作的正确处理
- 清晰的操作状态显示

## 使用场景

### 系统插件操作
- FxPlug插件的卸载和重命名
- 系统模板目录的操作
- 需要管理员权限的文件操作

### FxFactory插件防护
- 批量删除FxFactory管理文件
- 一次性清理多个相关文件
- 避免重复权限请求

### 批量操作
- 多个插件的批量卸载
- 类别目录的批量合并
- 大量文件的批量处理

## 用户界面

### 权限状态指示器
位于应用底部的状态栏显示：
- 🟢 **绿色**: 权限已授权，可以执行操作
- 🔵 **蓝色**: 正在请求权限
- 🔴 **红色**: 权限错误或被拒绝
- ⚪ **灰色**: 权限未授权（默认状态）

### 菜单命令
- **清除权限会话** (⌘⇧R): 手动清除当前权限会话

## 技术实现

### 使用示例
```swift
// 删除文件
try await SudoPermissionManager.shared.deleteFileWithSudoPermission(at: path)

// 重命名文件
try await SudoPermissionManager.shared.renameFileWithSudoPermission(from: oldPath, to: newPath)

// 批量删除
try await SudoPermissionManager.shared.deleteFilesWithSudoPermission(paths)

// 批量卸载插件（只需输入一次密码）
try await pluginManager.batchUninstallPlugins(plugins)

// 批量合并插件（只需输入一次密码）
try await pluginManager.batchMergePluginsToCategory(plugins, targetCategoryPath: "目标类别")
```

### 批量操作优化
- **批量卸载**：`batchUninstallPlugins` 方法将所有需要权限的插件路径合并为一个命令执行
- **批量合并**：`batchMergePluginsToCategory` 方法将所有移动操作合并为一个命令执行
- **类别合并**：`BatchMergeManager` 中的移动操作也已优化为批量执行

## 优势对比

### 旧系统 (逐个操作)
- ❌ 每个插件都需要输入密码
- ❌ 用户体验差，操作繁琐
- ❌ 批量操作需要多次授权

### 新系统 (批量操作优化)
- ✅ 批量操作只需输入一次密码
- ✅ 智能分组：系统插件和普通插件分别处理
- ✅ 合并命令：多个操作合并为一个 AppleScript 命令
- ✅ 统一的权限管理接口

## 安全考虑

### 会话超时
- 5分钟自动超时，平衡安全性和便利性
- 超时后不会主动弹出密码框，只在下次需要权限操作时才请求
- 应用退出时自动清理权限会话
- 用户可以手动清除权限会话

### 权限范围
- 只授权执行特定的文件操作
- 不会获取系统级别的完整管理员权限
- 遵循最小权限原则

## 故障排除

### 权限被拒绝
1. 检查用户是否有管理员权限
2. 确认密码输入正确
3. 尝试清除权限会话后重新操作

### 会话超时
1. 权限会话5分钟后自动超时
2. 超时后不会主动弹出密码框，只在下次需要权限操作时才请求
3. 可以通过菜单手动清除会话
4. 优化用户体验，避免频繁弹出密码框

### 操作失败
1. 检查文件是否被其他程序占用
2. 确认文件路径是否正确
3. 查看权限状态指示器的错误信息

## 开发调试

### 测试视图
`AuthorizationTestView` 提供了完整的权限系统测试功能：
- 权限请求测试
- 文件操作测试
- 会话管理测试
- 错误处理测试

### 日志输出
系统会输出详细的权限操作日志，便于调试：
```
🔐 开始权限请求流程...
🔐 当前权限状态: isAuthorized=false, authRef=不存在
🆕 创建新的权限会话（需要输入密码）...
✅ 权限授权成功，会话开始时间: 2025-07-15 09:51:22 +0000
✅ 权限引用已保存，后续操作将重用此权限
🔍 检查权限会话有效性...
🔍 会话已持续 120 秒，超时时间为 300 秒
✅ 使用现有的权限会话，无需重新输入密码
✅ 成功删除文件: /path/to/file
🔒 权限会话已完全失效
```

## 未来扩展

### 可能的改进
1. 可配置的会话超时时间
2. 更细粒度的权限控制
3. 权限操作的撤销功能
4. 更丰富的状态指示

### 兼容性
- 保持与现有代码的完全兼容
- 渐进式迁移到新的权限系统
- 支持回退到旧的AppleScript方式
