# XcodeBuildMCP 工具安装和使用指南

## 📋 概述

XcodeBuildMCP 是一个强大的 Model Context Protocol (MCP) 工具，专门用于 Xcode 项目的构建、测试和管理。它提供了比标准 xcodebuild 命令更丰富的功能和更好的集成体验。

## 🚀 安装步骤

### 方法 1：使用 npm 全局安装（推荐）

```bash
# 安装最新版本
npm install -g xcodebuildmcp@latest

# 验证安装
xcodebuildmcp --version

# 运行诊断检查
npx --package xcodebuildmcp@latest xcodebuildmcp-diagnostic
```

### 方法 2：使用 npx 临时运行

```bash
# 无需安装，直接运行
npx xcodebuildmcp@latest

# 运行诊断
npx --package xcodebuildmcp@latest xcodebuildmcp-diagnostic
```

## 🔧 基本使用流程

### 1. 启动 XcodeBuildMCP 服务器

```bash
# 在项目目录中启动
cd /path/to/your/xcode/project
xcodebuildmcp
```

### 2. 发现项目和工作空间

```json
{
  "jsonrpc": "2.0", 
  "id": 1, 
  "method": "tools/call", 
  "params": {
    "name": "discover_projs", 
    "arguments": {
      "workspaceRoot": "/path/to/your/project"
    }
  }
}
```

### 3. 列出可用的 Schemes

**对于项目文件 (.xcodeproj)：**
```json
{
  "jsonrpc": "2.0", 
  "id": 2, 
  "method": "tools/call", 
  "params": {
    "name": "list_schems_proj", 
    "arguments": {
      "projectPath": "/path/to/project.xcodeproj"
    }
  }
}
```

**对于工作空间 (.xcworkspace)：**
```json
{
  "jsonrpc": "2.0", 
  "id": 2, 
  "method": "tools/call", 
  "params": {
    "name": "list_schems_ws", 
    "arguments": {
      "workspacePath": "/path/to/project.xcworkspace"
    }
  }
}
```

## 🏗️ 构建操作

### macOS 应用构建

**项目文件构建：**
```json
{
  "jsonrpc": "2.0", 
  "id": 3, 
  "method": "tools/call", 
  "params": {
    "name": "build_mac_proj", 
    "arguments": {
      "projectPath": "/path/to/project.xcodeproj",
      "scheme": "YourScheme",
      "configuration": "Debug",
      "arch": "arm64"
    }
  }
}
```

**工作空间构建：**
```json
{
  "jsonrpc": "2.0", 
  "id": 3, 
  "method": "tools/call", 
  "params": {
    "name": "build_mac_ws", 
    "arguments": {
      "workspacePath": "/path/to/project.xcworkspace",
      "scheme": "YourScheme",
      "configuration": "Debug"
    }
  }
}
```

### iOS 模拟器构建

```json
{
  "jsonrpc": "2.0", 
  "id": 4, 
  "method": "tools/call", 
  "params": {
    "name": "build_sim_name_proj", 
    "arguments": {
      "projectPath": "/path/to/project.xcodeproj",
      "scheme": "YourScheme",
      "simulatorName": "iPhone 16",
      "configuration": "Debug"
    }
  }
}
```

## 🧪 测试操作

### macOS 测试

```json
{
  "jsonrpc": "2.0", 
  "id": 5, 
  "method": "tools/call", 
  "params": {
    "name": "test_macos_proj", 
    "arguments": {
      "projectPath": "/path/to/project.xcodeproj",
      "scheme": "YourScheme",
      "configuration": "Debug"
    }
  }
}
```

### iOS 模拟器测试

```json
{
  "jsonrpc": "2.0", 
  "id": 6, 
  "method": "tools/call", 
  "params": {
    "name": "test_sim_name_proj", 
    "arguments": {
      "projectPath": "/path/to/project.xcodeproj",
      "scheme": "YourScheme",
      "simulatorName": "iPhone 16"
    }
  }
}
```

## 🧹 清理操作

```json
{
  "jsonrpc": "2.0", 
  "id": 7, 
  "method": "tools/call", 
  "params": {
    "name": "clean_proj", 
    "arguments": {
      "projectPath": "/path/to/project.xcodeproj",
      "scheme": "YourScheme"
    }
  }
}
```

## 📱 模拟器管理

### 列出可用模拟器

```json
{
  "jsonrpc": "2.0", 
  "id": 8, 
  "method": "tools/call", 
  "params": {
    "name": "list_sims", 
    "arguments": {
      "enabled": true
    }
  }
}
```

### 启动模拟器

```json
{
  "jsonrpc": "2.0", 
  "id": 9, 
  "method": "tools/call", 
  "params": {
    "name": "boot_sim", 
    "arguments": {
      "simulatorUuid": "SIMULATOR_UUID_HERE"
    }
  }
}
```

## 🔍 构建设置查看

```json
{
  "jsonrpc": "2.0", 
  "id": 10, 
  "method": "tools/call", 
  "params": {
    "name": "show_build_set_proj", 
    "arguments": {
      "projectPath": "/path/to/project.xcodeproj",
      "scheme": "YourScheme"
    }
  }
}
```

## 📦 Swift Package 操作

### 构建 Swift Package

```json
{
  "jsonrpc": "2.0", 
  "id": 11, 
  "method": "tools/call", 
  "params": {
    "name": "swift_package_build", 
    "arguments": {
      "packagePath": "/path/to/swift/package",
      "configuration": "debug"
    }
  }
}
```

### 测试 Swift Package

```json
{
  "jsonrpc": "2.0", 
  "id": 12, 
  "method": "tools/call", 
  "params": {
    "name": "swift_package_test", 
    "arguments": {
      "packagePath": "/path/to/swift/package"
    }
  }
}
```

## ⚠️ 常见问题和解决方案

### 1. 权限问题
```bash
# 如果遇到权限问题，使用 sudo 安装
sudo npm install -g xcodebuildmcp@latest
```

### 2. 路径问题
- 确保所有路径都是绝对路径
- 检查项目文件是否存在
- 验证 scheme 名称是否正确

### 3. 模拟器问题
- 确保 Xcode 已安装并配置正确
- 检查模拟器是否可用：`xcrun simctl list`

### 4. 网络问题
```bash
# 使用国内镜像安装
npm install -g xcodebuildmcp@latest --registry=https://registry.npmmirror.com
```

## 🎯 最佳实践

1. **项目发现**：总是先使用 `discover_projs` 来发现项目
2. **Scheme 列表**：使用 `list_schems_proj/ws` 获取正确的 scheme 名称
3. **错误处理**：检查返回的 JSON 中的 `isError` 字段
4. **路径规范**：使用绝对路径避免路径问题
5. **资源清理**：定期使用 `clean_proj/ws` 清理构建产物

## 📚 参考资源

- [XcodeBuildMCP GitHub](https://github.com/cameroncooke/XcodeBuildMCP)
- [MCP 协议文档](https://modelcontextprotocol.io/)
- [Xcode 命令行工具文档](https://developer.apple.com/documentation/xcode)

## 💡 FCPX 插件管理器项目示例

### 完整的构建流程示例

```bash
# 1. 启动 XcodeBuildMCP 服务器
cd /Users/dayu/Documents/TemplatesArchive/TemmplatesArchive
xcodebuildmcp
```

```json
# 2. 发现项目
{"jsonrpc": "2.0", "id": 1, "method": "tools/call", "params": {"name": "discover_projs", "arguments": {"workspaceRoot": "/Users/dayu/Documents/TemplatesArchive/TemmplatesArchive"}}}

# 3. 列出 schemes
{"jsonrpc": "2.0", "id": 2, "method": "tools/call", "params": {"name": "list_schems_proj", "arguments": {"projectPath": "/Users/dayu/Documents/TemplatesArchive/TemmplatesArchive/TemmplatesArchive.xcodeproj"}}}

# 4. 构建 macOS 应用
{"jsonrpc": "2.0", "id": 3, "method": "tools/call", "params": {"name": "build_mac_proj", "arguments": {"projectPath": "/Users/dayu/Documents/TemplatesArchive/TemmplatesArchive/TemmplatesArchive.xcodeproj", "scheme": "TemmplatesArchive", "configuration": "Debug"}}}

# 5. 运行测试（如果有）
{"jsonrpc": "2.0", "id": 4, "method": "tools/call", "params": {"name": "test_macos_proj", "arguments": {"projectPath": "/Users/dayu/Documents/TemplatesArchive/TemmplatesArchive/TemmplatesArchive.xcodeproj", "scheme": "TemmplatesArchive"}}}

# 6. 构建并运行
{"jsonrpc": "2.0", "id": 5, "method": "tools/call", "params": {"name": "build_run_mac_proj", "arguments": {"projectPath": "/Users/dayu/Documents/TemplatesArchive/TemmplatesArchive/TemmplatesArchive.xcodeproj", "scheme": "TemmplatesArchive"}}}
```

## 🔄 版本信息

- **当前版本**：1.10.4
- **支持平台**：macOS, iOS, watchOS, tvOS, visionOS
- **依赖**：Node.js, Xcode Command Line Tools

## 📝 使用记录

- **安装日期**：2025-01-05
- **项目路径**：`/Users/dayu/Documents/TemplatesArchive/TemmplatesArchive`
- **项目文件**：`TemmplatesArchive.xcodeproj`
- **主要 Scheme**：`TemmplatesArchive`
- **目标平台**：macOS (SwiftUI)
